#!/bin/bash
#
# This scripts configures (tested with 10.8 and 10.9):
#
# LDAP		: configiguration for Contacts/Search Settings and LDAP configuration for ldap.science.uu.nl
# KERBEROS	: configuration for use with Active Directory Domain SOLISCOM.UU.NL 
# Automount	: configuration of automounter to add REMOTEMOUNTPOINT at startup (mounted on /mnt)
# Userlogon	: Add plist USERSTARTUPPLIST, script USERSCRIPT executes when user logs on
# SystemStartup : Add plist SYSTEMSTARTUPPLIST, script SYSTEMSTARTUPFILE executes when computer starts
#		  SYSTEMSTARTUPFILE executes the script REMOTESYSTEMSTARTUPFFILE
#		  SYSTEMSTARTUPFILE executes when mountpoint is available
# Localadmin	: Adds ldap.science.uu.nl group LOCALADMINGROUP to admin group on workstation
# MISC		: Allow networkusers to logon
#		  Modify LoginWindow (don't show list of users)
#
# HOWTO: 	  Download files install.sh, ldap.science.uu.nl.plist, Search.plist, Contacts.plist
#	          Execute: sudo install.sh and reboot machine
#
# Rob van den Broek, ICT-Beta, 12 maart 2014
#


KRBFILE="/etc/krb5.conf"

FORCESMBV1=TRUE

 
USERSTARTUPPLIST="/Library/LaunchAgents/com.user.startup.plist"
USERSCRIPT="/mnt/clients-local/osx/mi/user.sh"			

SYSTEMSTARTUP=TRUE							# Set FALSE if you don't want a system startup file
SYSTEMSTARTUPPLIST="/Library/LaunchDaemons/com.system.startup.plist"
SYSTEMSTARTUPFILE="/usr/local/sbin/system.sh"
REMOTESYSTEMSTARTUPFILE="/mnt/clients-local/osx/mi/system.sh"

CREATEMOUNT=TRUE							# set FALSE if no mountpoint should be created, only SMB is supported
MOUNTPOINT="/mnt/clients-local"
REMOTEMOUNTPOINT="GUEST@projects.science.uu.nl/clients-local"

MODLOCALADMIN=TRUE							# LOCALADMINGROUP is added to admin group, set FALSE is no modification is needed
LOCALADMINGROUP="science_osxadmin_mi"					# this can be an BSSP group, so groupmembers can be modified by a list of users

MODLOGINWINDOW=TRUE							# Enable show user/password at loginwindow history no list users, set FALSE if no modification is needed

#
# Create mount directory $MOUNTPOINT
# and mount $REMOTEMOUNTPOINT
#

if $CREATEMOUNT; then
  if [ ! -d /mnt ]; then
	mkdir /mnt
	echo Created Directory /mnt
  fi

  if [ ! -d $MOUNTPOINT ] ; then
	mkdir $MOUNTPOINT
	echo Created Directory $MOUNTPOINT
  fi

  if grep $MOUNTPOINT "/etc/auto_smb"; then
	echo Okee /etc/auto_smb
  else
	echo "$MOUNTPOINT -fstype=smbfs,soft ://REMOTEMOUNTPOINT" >> /etc/auto_smb
	echo Added entry $MOUNTPOINT to /etc/auto_smb
  fi

  if grep auto_smb  "/etc/auto_master"; then
	echo Okee /etc/auto_master
  else
	echo "/-                      auto_smb         -nosuid" >> /etc/auto_master
	echo "Added auto_smb to /etc/auto_master"
  fi
else
  ECHO Skipping CREATEMOUNT
fi


#
# Create /usr/local/sbin
#
if [ ! -d /usr/local ]; then
	mkdir /usr/local
	echo Created Directory /usr/local
fi


if [ ! -d /usr/local/sbin ]; then
	mkdir /usr/local/sbin
	echo Created Directory /usr/local/sbin
fi




#
# Create $SYSTEMSTARTUPPLIST
#
if $SYSTEMSTARTUP; then
   #
   # Create $SYSTEMSTARTUPFILE
   #
   if [ ! -f $SYSTEMSTARTUPFILE ]; then
	echo "#!/bin/bash" > $SYSTEMSTARTUPFILE
	echo "while true" >> $SYSTEMSTARTUPFILE
	echo "do" >> $SYSTEMSTARTUPFILE
	echo "        [ -f $REMOTESYSTEMSTARTUPFILE ] && break" >> $SYSTEMSTARTUPFILE
	echo "        sleep 2" >> $SYSTEMSTARTUPFILE
	echo "done" >> $SYSTEMSTARTUPFILE
	echo $REMOTESYSTEMSTARTUPFILE >> $SYSTEMSTARTUPFILE
	chmod +x $SYSTEMSTARTUPFILE
	echo Created $SYSTEMSTARTUPFILE
   else
		echo Okee $SYSTEMSTARTUPFILE
   fi

  if [ ! -f $SYSTEMSTARTUPPLIST ]; then
	echo "<?xml version="1.0" encoding="UTF-8"?>" >> $SYSTEMSTARTUPPLIST
	echo "<!DOCTYPE plist PUBLIC "-//Apple Computer//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">" >> $SYSTEMSTARTUPPLIST
	echo "<plist version="1.0">" >> $SYSTEMSTARTUPPLIST
	echo "<dict>" >> $SYSTEMSTARTUPPLIST
	echo "   <key>Label</key>" >> $SYSTEMSTARTUPPLIST
	echo "   <string>com.system.startup</string>" >> $SYSTEMSTARTUPPLIST
	echo "   <key>ProgramArguments</key>" >> $SYSTEMSTARTUPPLIST
	echo "   <array>" >> $SYSTEMSTARTUPPLIST
	echo "   <string>$SYSTEMSTARTUPFILE</string>" >> $SYSTEMSTARTUPPLIST
	echo "   </array>" >> $SYSTEMSTARTUPPLIST
	echo "   <key>RunAtLoad</key>" >> $SYSTEMSTARTUPPLIST
	echo "   <true/>" >> $SYSTEMSTARTUPPLIST
	echo "</dict>" >> $SYSTEMSTARTUPPLIST
	echo "</plist>" >> $SYSTEMSTARTUPPLIST
	echo Created $SYSTEMSTARTUPPLIST
	else
	echo Okee $SYSTEMSTARTUPPLIST 
   fi 
else
   Echo Skipping creating SYSTEMSTARTUP file
fi   

#
# Create $USERSTARTUPPLIST
#

if [ ! -f $USERSTARTUPPLIST ]; then 
echo "<?xml version="1.0" encoding="UTF-8"?>" > $USERSTARTUPPLIST
echo "<!DOCTYPE plist PUBLIC "-//Apple Computer//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">"  >>$USERSTARTUPPLIST
echo "<plist version="1.0">" >>$USERSTARTUPPLIST
echo "<dict>" >>$USERSTARTUPPLIST
echo "	<key>Label</key>" >>$USERSTARTUPPLIST
echo "	<string>com.user.loginscript</string>" >>$USERSTARTUPPLIST
echo "	<key>Program</key>" >>$USERSTARTUPPLIST
echo "	<string>$USERSCRIPT</string>" >>$USERSTARTUPPLIST
echo "	<key>RunAtLoad</key>" >>$USERSTARTUPPLIST
echo "	<true/>" >>$USERSTARTUPPLIST
echo "</dict>" >>$USERSTARTUPPLIST
echo "</plist>" >>$USERSTARTUPPLIST
echo Created $USERSTARTUPPLIST
else
echo Okee $USERSTARTUPPLIST
fi

#
# Create $KRBFILE for the Windows domain SOLISCOM.UU.NL
#
if [ ! -f $KRBFILE ]; then
echo "[logging]" >> $KRBFILE
echo "default = FILE:/var/log/krb5libs.log" >> $KRBFILE
echo "kdc = FILE:/var/log/krb5libs.log" >> $KRBFILE
echo "admin_server = FILE:/var/log/kadmind.log" >> $KRBFILE
echo "" >> $KRBFILE
echo "[libdefaults]" >> $KRBFILE
echo "                default_realm = SOLISCOM.UU.NL" >> $KRBFILE
echo "                dns_lookup_realm = true" >> $KRBFILE
echo "                dns_lookup_kdc = true" >> $KRBFILE
echo "                ticket_lifetime = 24h" >> $KRBFILE
echo "                forwardable = true" >> $KRBFILE
echo "                noaddresses = true" >> $KRBFILE
echo "" >> $KRBFILE
echo "[realms]" >> $KRBFILE
echo "SOLISCOM.UU.NL = {" >> $KRBFILE
echo "                kdc = SOLISCOM.UU.NL:88" >> $KRBFILE
echo "                admin_server = SOLISCOM.UU.NL:749" >> $KRBFILE
echo "}" >> $KRBFILE
echo "" >> $KRBFILE
echo "[domain_realm]" >> $KRBFILE
echo "soliscom.uu.nl = SOLISCOM.UU.NL" >> $KRBFILE
echo ".soliscom.uu.nl = SOLISCOM.UU.NL" >> $KRBFILE
echo "" >> $KRBFILE
echo "[appdefaults]" >> $KRBFILE
echo "pam = {" >> $KRBFILE
echo "                debug = true" >> $KRBFILE
echo "                ticket_lifetime = 36000" >> $KRBFILE
echo "                renew_lifetime = 36000" >> $KRBFILE 
echo "                forwardable = true" >> $KRBFILE
echo "                krb4convert = false" >> $KRBFILE
echo "}" >> $KRBFILE
echo Created $KRBFILE
else
echo Okee $KRBFILE
fi


#
# LoginWindow StartupDelay
#
/usr/bin/defaults write /Library/Preferences/com.apple.loginwindow StartupDelay -int 60

#
# Modify pam authorization file to use Kerberos
#
if grep "auth       optional       pam_krb5.so use_first_pass use_kcminit default_principal" "/etc/pam.d/authorization"; then
	echo "Okee PAM authorization"
else	
/usr/bin/perl -pi -e 's/auth       optional       pam_krb5.so use_first_pass use_kcminit/auth       optional       pam_krb5.so use_first_pass use_kcminit default_principal
auth       sufficient     pam_krb5.so use_first_pass default_principal/g' "/etc/pam.d/authorization"
echo "PAM config modified"
fi

#
# Modify LDAP configuration
#
if  [ ! -d "/Library/Preferences/OpenDirectory/Configurations/LDAPv3" ]; then
	mkdir "/Library/Preferences/OpenDirectory/Configurations/LDAPv3"
	echo "Created LDAPv3"
fi	

if [ -f "/Library/Preferences/OpenDirectory/Configurations/LDAPv3/ldap.science.uu.nl.plist" ]; then
	echo "Okee LDAP"
else
	cp Search.plist "/Library/Preferences/OpenDirectory/Configurations/"
	cp Contacts.plist "/Library/Preferences/OpenDirectory/Configurations/"
	cp ldap.science.uu.nl.plist "/Library/Preferences/OpenDirectory/Configurations/LDAPv3/"
	echo "LDAP installed"
fi

#
# Add $LOCALADMINGROUP to local admin group
#
if $MODLOCALADMIN; then
  echo ADD $LOCALADMINGROUP to admin group
  dseditgroup -o edit -a $LOCALADMINGROUP -t group -n /Local/Default admin
else
  Echo Skipping modification of localadmin group
fi

#
# Enable logins for Network Users at the LoginWindow
# Not working no active LDAP connection
# ECHO Enable logins for Network Users at the LoginWindow
# /usr/bin/defaults write /Library/Preferences/com.apple.loginwindow SHOWFULLNAME -bool "TRUE"

#
# Modify Loginwindow
#
if $MODLOGINWINDOW; then
  echo Enable show user/password at loginwindowhistory no list users
  /usr/bin/defaults write /Library/Preferences/com.apple.loginwindow SHOWFULLNAME -bool TRUE
else
  echo No modification of loginWindow
fi

#
# Force SMB v1, Maverick is buggy
#
if $FORCESMBV1; then
 if [ ! -f /etc/nsmb.conf ]; then
   echo "Create /etc/nsmb.conf"
   echo "[default]" > /etc/nsmb.conf
   echo "smb_neg=smb1_only" >> /etc/nsmb.conf
 fi
fi 